@@ -1,9 +1,7 @@
-from .offset_pagination import OffsetPaginationConnectionField
 from .data_source import DataSourceConnectionField
 from .data_source_allow_any import DataSourceAllowAnyConnectionField
 
 __all__ = (  # noqa: WPS410
-    "OffsetPaginationConnectionField",
     "DataSourceConnectionField",
     "DataSourceAllowAnyConnectionField",
 )
